/***************************************************************************
                          sambaoption.h  -  description
                             -------------------
    begin                : Tue Jan  7 15:33:56 CET 2003
    copyright            : (C) 2003 by Jan Schfer
    email                : janschaefer@users.sourceforge.net
 ***************************************************************************/

/******************************************************************************
 *                                                                            *
 *  This file is part of KSambaPlugin.                                        * 
 *                                                                            *
 *  KSambaPlugin is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  (at your option) any later version.                                       *
 *                                                                            *
 *  KSambaPlugin is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with KSambaPlugin; if not, write to the Free Software                     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA  *
 *                                                                            *
 ******************************************************************************/

#ifndef _SAMBAOPTION_H_
#define _SAMBAOPTION_H_

#include <qwidget.h>
#include <qwidgetplugin.h>


class QLineEdit;
class QCheckBox;
class QLabel;
class QSpinBox;
class KUrlRequester;
class SambaShare;
class QToolButton;
class QHBoxLayout;

class QT_WIDGET_PLUGIN_EXPORT SambaOption : public QWidget
{
  Q_OBJECT

  Q_ENUMS( WarningKind )
  Q_PROPERTY( WarningKind warningKind READ warningKind WRITE setWarningKind )
  Q_PROPERTY( QString warningString READ warningString WRITE setWarningString )
  Q_PROPERTY( QString sambaOption READ sambaOption WRITE setSambaOption )
  Q_PROPERTY( QString label READ label WRITE setLabel )
  Q_PROPERTY( bool isGlobalOption READ isGlobalOption WRITE setGlobalOption )

  public :

    enum WarningKind {  None, Warning, Information, Critical };

    SambaOption( QWidget *parent = 0, const char *name = 0);

    virtual void load() = 0;
    virtual void save() = 0;

    virtual void setSambaShare( SambaShare* share );
    SambaShare* sambaShare() const;

    WarningKind warningKind() const;
    QString warningString() const;
    QString sambaOption() const;
    bool isGlobalOption() const;
    virtual QString label() const = 0;
    

  signals :
    void changed();
    void warning(const QString &);

  protected slots :
    virtual void updateWarning();
    
  public slots:
    void setWarningKind( WarningKind );
    virtual void setWarningString( const QString & );
    virtual void setSambaOption( const QString & );
    virtual void setGlobalOption( bool);
    virtual void showWarning(bool);
    virtual void setLabel(const QString &) = 0;
    virtual void setToDefault();

  protected :
  
  
    WarningKind _warningKind;
    QString _warningString;
    QString _sambaOption;
    SambaShare* _sambaShare;
    bool _isGlobalOption;

    QToolButton* _defaultBtn;
    QLabel* _warningPix;
    QHBoxLayout* _layout;

};

class QT_WIDGET_PLUGIN_EXPORT SambaOptionCheckBox : public SambaOption
{
  Q_OBJECT

  Q_ENUMS( WarningEvent )
  Q_PROPERTY( WarningEvent warningEvent READ warningEvent WRITE setWarningEvent );

  public :
    enum WarningEvent { None, isChecked, isNotChecked };

    SambaOptionCheckBox( QWidget *parent = 0, const char *name = 0);

    virtual void load();
    virtual void save();

    WarningEvent warningEvent() const;
    void setWarningEvent( WarningEvent warningEvent );
  
    virtual QString label() const;
    
  protected slots :
    void changedSlot();  
    virtual void updateWarning();
      
  public slots :
    virtual void setLabel(const QString &);
      

  protected :
    QCheckBox* _checkBox;
    WarningEvent _warningEvent;
};

#endif

